@@ -113,6 +113,7 @@ class PhonopyYaml(object):
         self.u2p_map = [u2u_map[i] for i in (s2u_map[self.s2p_map])[u2s_map]]
         self.nac_params = phonopy.nac_params
         self.frequency_unit_conversion_factor = phonopy.unit_conversion_factor
+        self.calculator = phonopy.calculator
 
         if self.command_name == "phonopy":
             self.force_constants = phonopy.force_constants
@@ -137,6 +138,9 @@ class PhonopyYaml(object):
         if self.frequency_unit_conversion_factor:
             lines.append("  frequency_unit_conversion_factor: %f" %
                          self.frequency_unit_conversion_factor)
+        if self.symmetry:
+            lines.append("  symmetry_tolerance: %.5e" %
+                         self.symmetry.get_symmetry_tolerance())
         if self.nac_params:
             lines.append("  nac_unit_conversion_factor: %f" % nac_factor)
         if self.configuration is not None:
@@ -243,7 +247,7 @@ class PhonopyYaml(object):
             lines += self._displacements_yaml_lines()
 
         if self.settings['force_constants']:
-            lines += self.force_constants_yaml_lines()
+            lines += self._force_constants_yaml_lines()
 
         return lines
 
@@ -435,7 +439,7 @@ class PhonopyYaml(object):
     def _parse_force_sets_type2(self):
         nsets = len(self.yaml['displacements'])
         natom = len(self.yaml['displacements'][0])
-        if 'forces' in self.yaml['displacements'][0]:
+        if 'force' in self.yaml['displacements'][0][0]:
             with_forces = True
             forces = np.zeros((nsets, natom, 3), dtype='double', order='C')
         else:
